@@ -34,16 +34,42 @@ class BpmnDiagramGraphExport(object):
             output_element.set(consts.Consts.default, node_params[consts.Consts.default])
 
     @staticmethod
-    def export_subprocess_info(node_params, output_element):
+    def export_subprocess_info(bpmn_diagram, subprocess_params, output_element):
         """
         Adds Subprocess node attributes to exported XML element
 
-        :param node_params: dictionary with given subprocess parameters,
+        :param bpmn_diagram: BPMNDiagramGraph class instantion representing a BPMN process diagram,
+        :param subprocess_params: dictionary with given subprocess parameters,
         :param output_element: object representing BPMN XML 'subprocess' element.
         """
-        output_element.set(consts.Consts.triggered_by_event, node_params[consts.Consts.triggered_by_event])
-        if consts.Consts.default in node_params and node_params[consts.Consts.default] is not None:
-            output_element.set(consts.Consts.default, node_params[consts.Consts.default])
+        output_element.set(consts.Consts.triggered_by_event, subprocess_params[consts.Consts.triggered_by_event])
+        if consts.Consts.default in subprocess_params and subprocess_params[consts.Consts.default] is not None:
+            output_element.set(consts.Consts.default, subprocess_params[consts.Consts.default])
+
+        # for each node in graph add correct type of element, its attributes and BPMNShape element
+        subprocess_id = subprocess_params[consts.Consts.id]
+        nodes = bpmn_diagram.get_nodes_list_by_process_id(subprocess_id)
+        for node in nodes:
+            node_id = node[0]
+            params = node[1]
+            BpmnDiagramGraphExport.export_node_data(bpmn_diagram, node_id, params, output_element)
+
+        # for each edge in graph add sequence flow element, its attributes and BPMNEdge element
+        flows = bpmn_diagram.get_flows_list_by_process_id(subprocess_id)
+        for flow in flows:
+            params = flow[2]
+            BpmnDiagramGraphExport.export_flow_process_data(params, output_element)
+
+    @staticmethod
+    def export_data_object_info(bpmn_diagram, data_object_params, output_element):
+        """
+        Adds DataObject node attributes to exported XML element
+
+        :param bpmn_diagram: BPMNDiagramGraph class instantion representing a BPMN process diagram,
+        :param data_object_params: dictionary with given subprocess parameters,
+        :param output_element: object representing BPMN XML 'subprocess' element.
+        """
+        output_element.set(consts.Consts.is_collection, data_object_params[consts.Consts.is_collection])
 
     # TODO Complex gateway not fully supported
     #  need to find out how sequence of conditions is represented in BPMN 2.0 XML
@@ -86,7 +112,7 @@ class BpmnDiagramGraphExport(object):
     @staticmethod
     def export_parallel_gateway_info(node_params, output_element):
         """
-        Adds Subprocess node attributes to exported XML element
+        Adds parallel gateway node attributes to exported XML element
 
         :param node_params: dictionary with given parallel gateway parameters,
         :param output_element: object representing BPMN XML 'parallelGateway' element.
@@ -144,6 +170,25 @@ class BpmnDiagramGraphExport(object):
             if definition_id != "":
                 output_definition.set(consts.Consts.id, definition_id)
 
+    @staticmethod
+    def export_boundary_event_info(node_params, output_element):
+        """
+        Adds IntermediateCatchEvent attributes to exported XML element
+
+        :param node_params: dictionary with given intermediate catch event parameters,
+        :param output_element: object representing BPMN XML 'intermediateCatchEvent' element.
+        """
+        output_element.set(consts.Consts.parallel_multiple, node_params[consts.Consts.parallel_multiple])
+        output_element.set(consts.Consts.cancel_activity, node_params[consts.Consts.cancel_activity])
+        output_element.set(consts.Consts.attached_to_ref, node_params[consts.Consts.attached_to_ref])
+        definitions = node_params[consts.Consts.event_definitions]
+        for definition in definitions:
+            definition_id = definition[consts.Consts.id]
+            definition_type = definition[consts.Consts.definition_type]
+            output_definition = eTree.SubElement(output_element, definition_type)
+            if definition_id != "":
+                output_definition.set(consts.Consts.id, definition_id)
+
     @staticmethod
     def export_definitions_element():
         """
@@ -262,10 +307,11 @@ class BpmnDiagramGraphExport(object):
         return diagram, plane
 
     @staticmethod
-    def export_node_process_data(process_id, params, process):
+    def export_node_data(bpmn_diagram, process_id, params, process):
         """
         Creates a new XML element (depends on node type) for given node parameters and adds it to 'process' element.
 
+        :param bpmn_diagram: BPMNDiagramGraph class instantion representing a BPMN process diagram,
         :param process_id: string representing ID of given flow node,
         :param params: dictionary with node parameters,
         :param process: object of Element class, representing BPMN XML 'process' element (root for nodes).
@@ -275,17 +321,22 @@ class BpmnDiagramGraphExport(object):
         output_element.set(consts.Consts.id, process_id)
         output_element.set(consts.Consts.name, params[consts.Consts.node_name])
 
-        for incoming in params[consts.Consts.incoming_flows]:
-            incoming_element = eTree.SubElement(output_element, consts.Consts.incoming_flows)
+        for incoming in params[consts.Consts.incoming_flow]:
+            incoming_element = eTree.SubElement(output_element, consts.Consts.incoming_flow)
             incoming_element.text = incoming
-        for outgoing in params[consts.Consts.outgoing_flows]:
-            outgoing_element = eTree.SubElement(output_element, consts.Consts.outgoing_flows)
+        for outgoing in params[consts.Consts.outgoing_flow]:
+            outgoing_element = eTree.SubElement(output_element, consts.Consts.outgoing_flow)
             outgoing_element.text = outgoing
 
-        if node_type == consts.Consts.task:
+        if node_type == consts.Consts.task \
+                or node_type == consts.Consts.user_task \
+                or node_type == consts.Consts.service_task \
+                or node_type == consts.Consts.manual_task:
             BpmnDiagramGraphExport.export_task_info(params, output_element)
         elif node_type == consts.Consts.subprocess:
-            BpmnDiagramGraphExport.export_subprocess_info(params, output_element)
+            BpmnDiagramGraphExport.export_subprocess_info(bpmn_diagram, params, output_element)
+        elif node_type == consts.Consts.data_object:
+            BpmnDiagramGraphExport.export_data_object_info(bpmn_diagram, params, output_element)
         elif node_type == consts.Consts.complex_gateway:
             BpmnDiagramGraphExport.export_complex_gateway_info(params, output_element)
         elif node_type == consts.Consts.event_based_gateway:
@@ -300,6 +351,8 @@ class BpmnDiagramGraphExport(object):
             BpmnDiagramGraphExport.export_catch_event_info(params, output_element)
         elif node_type == consts.Consts.end_event or node_type == consts.Consts.intermediate_throw_event:
             BpmnDiagramGraphExport.export_throw_event_info(params, output_element)
+        elif node_type == consts.Consts.boundary_event:
+            BpmnDiagramGraphExport.export_boundary_event_info(params, output_element)
 
     @staticmethod
     def export_node_di_data(node_id, params, plane):
@@ -391,6 +444,7 @@ class BpmnDiagramGraphExport(object):
                 message_flow.set(consts.Consts.source_ref, message_flow_attr[consts.Consts.source_ref])
                 message_flow.set(consts.Consts.target_ref, message_flow_attr[consts.Consts.target_ref])
 
+                tmp = bpmn_diagram.get_flow_by_id(message_flow_id)
                 message_flow_params = bpmn_diagram.get_flow_by_id(message_flow_id)[2]
                 output_flow = eTree.SubElement(plane, BpmnDiagramGraphExport.bpmndi_namespace + consts.Consts.bpmn_edge)
                 output_flow.set(consts.Consts.id, message_flow_id + "_gui")
@@ -429,15 +483,27 @@ class BpmnDiagramGraphExport(object):
             for node in nodes:
                 node_id = node[0]
                 params = node[1]
-                BpmnDiagramGraphExport.export_node_process_data(node_id, params, process)
-                BpmnDiagramGraphExport.export_node_di_data(node_id, params, plane)
+                BpmnDiagramGraphExport.export_node_data(bpmn_diagram, node_id, params, process)
+                # BpmnDiagramGraphExport.export_node_di_data(node_id, params, plane)
 
             # for each edge in graph add sequence flow element, its attributes and BPMNEdge element
             flows = bpmn_diagram.get_flows_list_by_process_id(process_id)
             for flow in flows:
                 params = flow[2]
                 BpmnDiagramGraphExport.export_flow_process_data(params, process)
-                BpmnDiagramGraphExport.export_flow_di_data(params, plane)
+                # BpmnDiagramGraphExport.export_flow_di_data(params, plane)
+
+        # Export DI data
+        nodes = bpmn_diagram.get_nodes()
+        for node in nodes:
+            node_id = node[0]
+            params = node[1]
+            BpmnDiagramGraphExport.export_node_di_data(node_id, params, plane)
+
+        flows = bpmn_diagram.get_flows()
+        for flow in flows:
+            params = flow[2]
+            BpmnDiagramGraphExport.export_flow_di_data(params, plane)
 
         BpmnDiagramGraphExport.indent(definitions)
         tree = eTree.ElementTree(definitions)
@@ -470,7 +536,7 @@ class BpmnDiagramGraphExport(object):
             for node in nodes:
                 node_id = node[0]
                 params = node[1]
-                BpmnDiagramGraphExport.export_node_process_data(node_id, params, process)
+                BpmnDiagramGraphExport.export_node_data(bpmn_diagram, node_id, params, process)
 
             # for each edge in graph add sequence flow element, its attributes and BPMNEdge element
             flows = diagram_graph.edges(data=True)
